@@ -1,4 +1,4 @@
-(* $Id: morph3d.ml,v 1.10.4.2 2004/03/11 01:19:43 garrigue Exp $ *)
+(* $Id: morph3d.ml,v 1.11 2003/02/20 06:47:48 garrigue Exp $ *)
 
 open StdLabels
 
@@ -606,4 +606,4 @@ let main () =
   window#show ();
   Main.main ()
 
-let () = if not !Sys.interactive then Printexc.print main ()
+let _ = main ()
