@@ -1,4 +1,4 @@
-(* $Id: rpn.ml,v 1.12 2001/09/06 08:47:55 garrigue Exp $ *)
+(* $Id: rpn.ml,v 1.13 2002/05/28 09:21:04 garrigue Exp $ *)
 
 (* reverse polish calculator *)
 
@@ -69,12 +69,7 @@ let main () =
   (* Period *)
   let periodClicked _ = 
      let txt = entry#text in
-     if (String.contains txt '.') then begin
-      	Printf.printf "\a";
-        flush stdout;
-     end
-     else
-       entry#append_text "." in
+     if not (String.contains txt '.') then entry#append_text "." in
   (GButton.button ~label:" . "
      ~packing:(table1#attach ~left:1 ~top:3 ~expand:`BOTH) ())
     #connect#clicked ~callback:periodClicked;
