@@ -1,4 +1,4 @@
-(* $Id: socket.ml,v 1.3 2000/05/22 03:14:59 garrigue Exp $ *)
+(* $Id: socket.ml,v 1.4 2004/01/13 05:49:52 garrigue Exp $ *)
 
 open GMain
 
@@ -7,10 +7,10 @@ let main () =
   w#connect#destroy ~callback:Main.quit;
   let vbox = GPack.vbox ~packing:w#add () in
   let label = GMisc.label ~packing:vbox#pack () in
-  let socket = GBin.socket ~packing:vbox#add ~height:40 () in
+  w#show ();
+  let socket = GWindow.socket ~packing:vbox#add ~height:40 () in
   label#set_text ("XID to plug into this socket: 0x" ^ 
                   Int32.format "%x" socket#xwindow);
-  w#show ();
   Main.main ()
 
 let _ = main ()
