@@ -293,15 +293,15 @@ class drag_handler = object
   method private beginning (_ : drag_context) = ()
   method private data_delete (_ : drag_context) = ()
   method private data_get (_ : drag_context) (_ : selection_context)
-      ~info:(_ : int) ~time:(_ : int) = ()
-  method private data_received (_ : drag_context) ~x:(_ : int) ~y:(_ : int)
-      (_ : selection_data) ~info:(_ : int) ~time:(_ : int) = ()
-  method private drop (_ : drag_context) ~x:(_ : int) ~y:(_ : int)
-      ~time:(_ : int) = false
+      ~(info : int) ~(time : int32) = ()
+  method private data_received (_ : drag_context) ~(x : int) ~(y : int)
+      (_ : selection_data) ~(info : int) ~(time : int32) = ()
+  method private drop (_ : drag_context) ~(x : int) ~(y : int)
+      ~(time : int32) = false
   method private ending (_ : drag_context) = ()
-  method private leave (_ : drag_context) ~time:(_ : int) = ()
-  method private motion (_ : drag_context) ~x:(_ : int) ~y:(_ : int)
-      ~time:(_ : int) = false
+  method private leave (_ : drag_context) ~(time : int32) = ()
+  method private motion (_ : drag_context) ~(x : int) ~(y : int)
+      ~(time : int32) = false
 end
 
 
@@ -328,7 +328,7 @@ object (self)
       with Gpointer.Null -> "unknown"
     in
     Printf.printf "motion, source %s\n" source_typename; flush stdout;
-    context#status [context#suggested_action] ~time;
+    context#status (Some context#suggested_action) ~time;
     true
 
   method drop context ~x ~y ~time =
@@ -403,7 +403,7 @@ end
 
 class popup () = object (self)
   inherit drag_handler
-  val mutable popup_window = (None : GWindow.window option)
+  val mutable popup_window = (None : #GWindow.window option)
   val mutable popped_up = false
   val mutable in_popup = false
   val mutable popdown_timer = None
