@@ -1,4 +1,4 @@
-(* $Id: gEdit.mli,v 1.33 2004/08/19 12:33:57 oandrieu Exp $ *)
+(* $Id: gEdit.mli,v 1.36 2005/03/07 20:19:50 oandrieu Exp $ *)
 
 open Gtk
 open GObj
@@ -116,6 +116,7 @@ class entry : ([> Gtk.entry] as 'a) obj ->
     method set_text : string -> unit
     method set_visibility : bool -> unit
     method set_width_chars : int -> unit
+    method set_xalign : float -> unit
     method activates_default : bool
     method editable : bool
     method has_frame : bool
@@ -123,6 +124,7 @@ class entry : ([> Gtk.entry] as 'a) obj ->
     method max_length : int
     method visibility : bool
     method width_chars : int
+    method xalign : float
 
     method set_completion : entry_completion -> unit (** @since GTK 2.4 *)
     method get_completion : entry_completion option  (** @since GTK 2.4 *)
@@ -137,6 +139,7 @@ val entry :
   ?editable:bool ->
   ?has_frame:bool ->
   ?width_chars:int ->
+  ?xalign:float ->
   ?width:int -> ?height:int ->
   ?packing:(widget -> unit) -> ?show:bool -> unit -> entry
 
@@ -265,6 +268,13 @@ class combo_box :
     method set_row_span_column : int GTree.column -> unit
     method set_wrap_width : int -> unit
     method wrap_width : int
+    method add_tearoffs : bool (** @since GTK 2.6 *)
+    method set_add_tearoffs : bool -> unit (** @since GTK 2.6 *)
+    method focus_on_click : bool (** @since GTK 2.6 *)
+    method set_focus_on_click : bool -> unit (** @since GTK 2.6 *)
+    method has_frame : bool (** @since GTK 2.6 *)
+    method set_has_frame : bool -> unit (** @since GTK 2.6 *)
+    method set_row_separator_func : (GTree.model -> Gtk.tree_iter -> bool) option -> unit (** @since GTK 2.6 *)
   end
 
 (** @since GTK 2.4
@@ -272,6 +282,9 @@ class combo_box :
 val combo_box :
   ?model:#GTree.model ->
   ?active:int ->
+  ?add_tearoffs:bool ->
+  ?focus_on_click:bool ->
+  ?has_frame:bool ->
   ?wrap_width:int ->
   ?width:int ->
   ?height:int ->
@@ -297,6 +310,9 @@ val combo_box_entry :
   ?model:#GTree.model ->
   ?text_column:string GTree.column ->
   ?active:int ->
+  ?add_tearoffs:bool ->
+  ?focus_on_click:bool ->
+  ?has_frame:bool ->
   ?wrap_width:int ->
   ?width:int ->
   ?height:int ->
@@ -320,7 +336,11 @@ val text_combo_get_active : 'a text_combo -> string option
     @gtkdoc gtk GtkComboBox *)
 val combo_box_text :
   ?strings:string list ->
+  ?use_markup:bool ->
   ?active:int ->
+  ?add_tearoffs:bool ->
+  ?focus_on_click:bool ->
+  ?has_frame:bool ->
   ?wrap_width:int ->
   ?width:int ->
   ?height:int ->
@@ -334,6 +354,9 @@ val combo_box_text :
 val combo_box_entry_text :
   ?strings:string list ->
   ?active:int ->
+  ?add_tearoffs:bool ->
+  ?focus_on_click:bool ->
+  ?has_frame:bool ->
   ?wrap_width:int ->
   ?width:int ->
   ?height:int ->
