@@ -1,13 +1,15 @@
-/* $Id: ml_gdkpixbuf.c,v 1.16 2004/10/02 01:09:43 garrigue Exp $ */
+/* $Id: ml_gdkpixbuf.c,v 1.17 2005/05/03 20:50:21 oandrieu Exp $ */
 
 #include <string.h>
 #include <gdk/gdk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gdk-pixbuf/gdk-pixdata.h>
 #include <caml/mlvalues.h>
 #include <caml/alloc.h>
 #include <caml/memory.h>
 #include <caml/callback.h>
 #include <caml/fail.h>
+#include <caml/intext.h>
 
 #include "wrappers.h"
 #include "ml_glib.h"
@@ -20,9 +22,91 @@
 
 #include "gdkpixbuf_tags.c"
 
+/* custom block with serialization for GdkPixbufs */
+static void ml_final_GdkPixbuf (value val)
+{ 
+  g_object_unref (GdkPixbuf_val(val)); 
+}
+
+static gboolean pixbuf_marshal_use_rle;
+
+CAMLprim value ml_gdk_pixbuf_set_marshal_use_rle (value v)
+{
+  pixbuf_marshal_use_rle = Bool_val (v);
+  return Val_unit;
+}
+
+static void ml_GdkPixbuf_serialize (value v, unsigned long *wsize_32, unsigned long *wsize_64)
+{
+  GdkPixbuf *pb = GdkPixbuf_val(v);
+  GdkPixdata pixdata;
+  guint8 *stream, *pixels;
+  guint len;
+  pixels = gdk_pixdata_from_pixbuf (&pixdata, pb, pixbuf_marshal_use_rle);
+  stream = gdk_pixdata_serialize (&pixdata, &len);
+  serialize_int_4 (len);
+  serialize_block_1 (stream, len);
+  g_free (stream);
+  g_free (pixels);
+  *wsize_32 = 4;
+  *wsize_64 = 8;
+}
+
+static unsigned long ml_GdkPixbuf_deserialize (void *dst)
+{
+  GError *error = NULL;
+  GdkPixdata pixdata;
+  GdkPixbuf *pb;
+  guint8 *stream;
+  guint len;
+
+  len = deserialize_uint_4();
+  stream = stat_alloc (len);
+  deserialize_block_1 (stream, len);
+  gdk_pixdata_deserialize (&pixdata, len, stream, &error);
+  if (error) goto out;
+  pb = gdk_pixbuf_from_pixdata (&pixdata, TRUE, &error);
+  if (error) goto out;
+  *(GdkPixbuf **)dst = pb;
+
+ out:
+  stat_free (stream);
+  if (error != NULL)
+    {
+      char *msg;
+      GEnumClass *class = G_ENUM_CLASS (g_type_class_peek (GDK_TYPE_PIXBUF_ERROR));
+      GEnumValue *val   = g_enum_get_value (class, error->code);
+      msg = val ? val->value_name : "";
+      g_error_free (error);
+      deserialize_error (msg);
+    }
+  return sizeof pb;
+}
+
+static struct custom_operations ml_custom_GdkPixbuf = { 
+  "GdkPixbuf/2.0/",
+  ml_final_GdkPixbuf,
+  custom_compare_default,
+  custom_hash_default,
+  ml_GdkPixbuf_serialize, ml_GdkPixbuf_deserialize
+};
+
+value Val_GdkPixbuf_ (GdkPixbuf *pb, gboolean ref)
+{ 
+  GdkPixbuf **p;
+  value ret; 
+  if (pb == NULL) ml_raise_null_pointer(); 
+  ret = alloc_custom (&ml_custom_GdkPixbuf, sizeof pb, 
+		      100, 1000);
+  p = Data_custom_val (ret);
+  *p = ref ? g_object_ref (pb) : pb;
+  return ret; 
+}
+
 CAMLprim value ml_gdkpixbuf_init(value unit)
 {
   ml_register_exn_map (GDK_PIXBUF_ERROR, "gdk_pixbuf_error");
+  register_custom_operations (&ml_custom_GdkPixbuf);
   return Val_unit;
 }
 
@@ -66,8 +150,23 @@ CAMLprim value ml_gdk_pixbuf_new_from_file_at_size(value f, value w, value h)
     if (err) ml_raise_gerror(err);
     return Val_GdkPixbuf_new(res);
 }
+
+CAMLprim value ml_gdk_pixbuf_get_file_info(value f)
+{
+  CAMLparam0();
+  CAMLlocal1(v);
+  gint w, h;
+  GdkPixbufFormat *fmt;
+  fmt = gdk_pixbuf_get_file_info (String_val (f), &w, &h);
+  v = alloc_tuple(3);
+  Store_field(v, 0, copy_string(gdk_pixbuf_format_get_name(fmt)));
+  Store_field(v, 1, Val_int(w));
+  Store_field(v, 2, Val_int(h));
+  CAMLreturn(v);
+}
 #else
 Unsupported_24 (gdk_pixbuf_new_from_file_at_size)
+Unsupported_24 (gdk_pixbuf_get_file_info)
 #endif
 ML_1(gdk_pixbuf_new_from_xpm_data, (const char**), Val_GdkPixbuf_new)
 
