@@ -1,4 +1,4 @@
-/* $Id: ml_glade.c,v 1.5.6.1 2003/04/09 14:45:32 furuse Exp $ */
+/* $Id: ml_glade.c,v 1.9 2004/09/21 11:29:37 oandrieu Exp $ */
 
 #include <string.h>
 #include <gtk/gtk.h>
@@ -11,6 +11,7 @@
 
 #include "wrappers.h"
 #include "ml_glib.h"
+#include "ml_gobject.h"
 #include "ml_gdk.h"
 #include "ml_gtk.h"
 
@@ -18,7 +19,15 @@
 ML_0 (glade_init, Unit)
 /* ML_0 (glade_gnome_init, Unit) */
 
-#define GladeXML_val(val) ((GladeXML*)GtkObject_val(val))
+#define GladeXML_val(val) (check_cast(GLADE_XML,val))
+
+/* glade_xml_new_with_domain and glade_xml_new_from_memory are deprecated */
+#ifndef glade_xml_new_with_domain
+#define glade_xml_new_with_domain glade_xml_new
+#endif
+#ifndef glade_xml_new_from_memory
+#define glade_xml_new_from_memory glade_xml_new_from_buffer
+#endif
 
 CAMLprim value ml_glade_xml_new (value file, value data, value root, value domain)
 {
@@ -33,29 +42,31 @@ CAMLprim value ml_glade_xml_new (value file, value data, value root, value domai
                                          String_option_val(root),
                                          String_option_val(domain));
     else invalid_argument ("Glade.create");
-    return Val_GtkAny_sink (ret);
+    return Val_GObject_new (&ret->parent);
 }
 
-#define set(variable, expr) {value tmp = expr; initialize(&variable, tmp);}
-
 void ml_glade_callback_marshal (const gchar *handler_name,
-                                GtkObject *object,
+                                GObject *object,
                                 const gchar *signal_name,
                                 const gchar *signal_data,
-                                GtkObject *connect_object,
+                                GObject *connect_object,
                                 gboolean after,
                                 gpointer user_data)
 {
     value vargs = alloc(5,0);
+    value tmp;
 
     CAMLparam1 (vargs);
+
+#define set(variable, expr) tmp = expr; initialize(&variable, tmp);
     set(Field(vargs,0), Val_string(handler_name));
-    set(Field(vargs,1), Val_GtkObject(object));
+    set(Field(vargs,1), Val_GObject(object));
     set(Field(vargs,2), Val_string(signal_name));
-    set(Field(vargs,3), Val_option(connect_object, Val_GtkObject));
+    set(Field(vargs,3), Val_option(connect_object, Val_GObject));
     set(Field(vargs,4), Val_bool(after));
+#undef set
     
-    callback (*(value*)user_data, vargs);
+    callback_exn (*(value*)user_data, vargs);
 
     CAMLreturn0;
 }
@@ -80,8 +91,5 @@ CAMLprim value ml_glade_xml_signal_connect_full (value self, value name, value c
 }
 
 ML_2 (glade_xml_get_widget, GladeXML_val, String_val, Val_GtkWidget)
-ML_2 (glade_xml_get_widget_by_long_name, GladeXML_val, String_val,
-      Val_GtkWidget)
 ML_1 (glade_get_widget_name, GtkWidget_val, Val_string)
-ML_1 (glade_get_widget_long_name, GtkWidget_val, Val_string)
 ML_1 (glade_get_widget_tree, GtkWidget_val, Val_GtkAny)
